@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 
 
 use 5.006;
@@ -37,7 +37,10 @@ sub import {
   my $pack = caller;
   my $test = Test::Builder->new;
   $test->exported_to($pack);
-  $test->plan(@_);
+  if(defined $_[0] && $_[0] =~ /^(?:no_plan|skip_all|tests)$/)
+  {
+    $test->plan(@_);
+  }
   foreach ( @EXPORT ) {
     $self->export_to_level(1, $self, $_);
   }
@@ -315,7 +318,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 SYNOPSIS
 
